#include "display_joystick.h"
#include <stdlib.h>
#include <stdbool.h>

void showPosition(int current, int target)
{
  char a[] = "        ";
  a[current] = 'o';
  if(current + 2 < 8)
  {
    a[current + 2] = '<';
  }
  if(current - 2 >= 0)
  {
    a[current - 2] = '>';
  }
  a[target] = 'T';
  writeString(a);
}

struct Waypoint
{
  int distance;
  int position;
};

typedef struct Waypoint Waypoint;

static const Waypoint tour[] =
{
  {   0, 4},
  { 100, 5},
  { 300, 6},
  { 400, 7},
  { 500, 6},
  { 550, 5},
  { 600, 4},
  { 650, 3},
  { 700, 2},
  { 750, 1},
  { 800, 0},
  { 900, 1},
  {1000, 2},
  {1100, 3},  
  {1200, 4},
  {1300,-1}
};

int main( void )
{
  initialize();
  const int millisecondsPerCycle = 30;
  
  while(true)
  {
    int round = 0;
    long time = 0;
    int errors = 0;
    
    int currentWaypoint = 0;
    int distance = 0;
    bool errorInPreviousStep = false;
    
    bool done = false;
    while(!done)
    {
      int speed = (readAnalog(1)-400)/20;
      distance += speed;
      
      while(distance >= tour[currentWaypoint+1].distance)
      {
        currentWaypoint++;
        if(tour[currentWaypoint].position < 0)
        {
          currentWaypoint = 0;
          distance = 0;
          round++;
          if(round == 5)
          {
            done = true;
          }
        }
      }
      
      int position = readAnalog(0)*8/1024;
      showPosition(position, tour[currentWaypoint].position);
      
      if(abs(position - tour[currentWaypoint].position) <= 2)
      {
        errorInPreviousStep = false;
      }
      else if(!errorInPreviousStep) // letztes Mal ok, jetzt falsch
      {
        errorInPreviousStep = true;
        errors++;
      }
      
      waitMilliseconds(millisecondsPerCycle);
      time += millisecondsPerCycle;
    }
    
    writeString("Time (s)");
    waitMilliseconds(1000);
    writeNumber(time/1000);
    waitMilliseconds(1000);
    writeString("Errors");
    waitMilliseconds(1000);
    writeNumber(errors);
    waitMilliseconds(1000);
    time = 0;
    errors = 0;
  }
    
  //return 0;
}